@@ -10,7 +10,8 @@ altmin <-
            trace.it = T,
            intercept = F,
            reff = T,
-           ceff = T)
+           ceff = T,
+           parallel=F)
   {
     Y <- as.matrix(Y)
     n <- nrow(Y)
@@ -37,6 +38,8 @@ altmin <-
     X <- sweep(X, 1, alpha, "+")
     X <- sweep(X, 2, beta, "+")
     Ytalp <- c(Y[!is.na(Y)])
+    alpha.step <- 1
+    theta.step <- 1
     while (error > thresh && count < maxit) {
       mu.tmp <- mu
       alpha.tmp <- alpha
@@ -49,17 +52,16 @@ altmin <-
       grad <- grad(Y, cov, mu, alpha, beta, epsilon, theta)
       if(!reff) grad[1:n] <- 0
       if(!ceff) grad[(n+1):(n+p)] <- 0
-      step <- 1
       flag <- TRUE
+      alpha.step <- 1
       Xtmp <- mu + theta + matrix(cov%*% epsilon, nrow=n)
       Xtmp <- sweep(Xtmp, 1, alpha, "+")
       Xtmp <- sweep(Xtmp, 2, beta, "+")
-      armijo.step <- 1
       ref.obj <-
-        sum((-Y * (Xtmp) + exp(Xtmp)),na.rm = T) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
+        sum((-Y * (Xtmp) + exp(Xtmp)),na.rm = T) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(alpha), abs(beta),abs(epsilon)))
       while(flag){
         #print(step)
-        maineff <- sign(c(alpha.tmp, beta.tmp, epsilon.tmp)-step*grad)*pmax(abs(c(alpha.tmp, beta.tmp, epsilon.tmp)-step*grad)-step*lambda2, 0)
+        maineff <- sign(c(alpha.tmp, beta.tmp, epsilon.tmp)-alpha.step*grad)*pmax(abs(c(alpha.tmp, beta.tmp, epsilon.tmp)-alpha.step*grad)-alpha.step*lambda2, 0)
         alpha <- maineff[1:n]
         beta <- maineff[(n+1):(n+p)]
         epsilon <- maineff[(n+p+1):(n+p+q)]
@@ -67,30 +69,28 @@ altmin <-
         Xtmp <- sweep(Xtmp, 1, alpha, "+")
         Xtmp <- sweep(Xtmp, 2, beta, "+")
         diff <-
-          sum((-Y * (Xtmp) + exp(Xtmp)), na.rm = T)  + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta))) - ref.obj
+          sum((-Y * (Xtmp) + exp(Xtmp)), na.rm = T)  + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(alpha), abs(beta),abs(epsilon))) - ref.obj
         flag <- diff > thresh * abs(ref.obj)
-        step <- 0.5*step
+        alpha.step <- 0.5*alpha.step
       }
       X <- Xtmp
       grad_theta <- (-Y2 + exp(X))
       grad_theta <- sweep(grad_theta, 2, colMeans(grad_theta))
       grad_theta <- sweep(grad_theta, 1, rowMeans(grad_theta))
-
+      theta.step <- 1
       flag <- TRUE
-      step <- 1
-      armijo.step <- 1
       ref.obj <-
-        sum((-Y * (X) + exp(X)), na.rm = T) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
+        sum((-Y * (X) + exp(X)), na.rm = T) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(alpha), abs(beta), abs(epsilon)))
       Xtmp <- mu + matrix(cov%*% epsilon, nrow=n)
       Xtmp <- sweep(Xtmp, 1, alpha, "+")
       Xtmp <- sweep(Xtmp, 2, beta, "+")
       while (flag) {
         #print(step)
-        svd_theta <- svd(theta - step * grad_theta, nu=rank.max, nv=rank.max)
+        svd_theta <- svd(theta - theta.step * grad_theta, nu=rank.max, nv=rank.max)
         d <- svd_theta$d[1:rank.max]
         u <- svd_theta$u[, 1:rank.max]
         v <- svd_theta$v[, 1:rank.max]
-        d <- d[d > (lambda1 * step)] - lambda1 * step
+        d <- d[d > (lambda1 * theta.step)] - lambda1 * theta.step
         if (length(d) == 0) {
           theta2 <- matrix(rep(0, n * p), nrow = n)
         } else if (length(d) == 1) {
@@ -103,14 +103,14 @@ altmin <-
           theta2 <- u %*% diag(d) %*% t(v)
         }
         diff <-
-          sum((-Y* (Xtmp + theta2) + exp(Xtmp+ theta2)), na.rm = T) + lambda1 * sum(d) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))- ref.obj
+          sum((-Y* (Xtmp + theta2) + exp(Xtmp+ theta2)), na.rm = T) + lambda1 * sum(d) + sum(lambda2 * c(abs(alpha), abs(beta),abs(epsilon)))- ref.obj
         flag <- diff > thresh * abs(ref.obj)
-        step <- 0.5 * step
+        theta.step <- 0.5 * theta.step
       }
       theta <- theta2
       X <- Xtmp + theta
       objective = c(objective,-sum((Y * X - exp(X)), na.rm = T)+ lambda1 *
-                      sum(d) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta))))
+                      sum(d) + sum(lambda2 * c(abs(alpha), abs(beta),abs(epsilon))))
       if(count==1){
         error <- 1
       } else{
